package p2;
our $VERSION = '0.02';

die "Sorry, p2 features not yet available for $^X";

1;
__END__

=head1 NAME

p2 - activate p2 extensions

=head1 SYNOPSIS

  use p2;
  # use extended p2 features and syntax, not found in p5p perl

=head1 DESCRIPTION

use p2 is used to enable extensions for the
experimental p2 perl5 implementation.

It needs to fail on p5p perl currently, but it would
be fantastic if these extensions can be used with p5p
perl also someday.

See L<http://perl11.org/p2/>

=head1 AUTHOR

Reini Urban, E<lt>rurban@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2013 by perl11.org

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.14 or,
at your option, any later version of Perl 5 you may have available.

=cut
